import { DialogSOP } from '../../libappsop/dialogsop';
import { EditFieldSOP } from '../../libappsop/editfieldsop';
import { CheckboxSOP } from '../../libappsop/checkboxsop';
import { DropDownListSOP } from '../../libappsop/dropdownlistsop';
import { DateTimeSelectorSOP } from '../../libappsop/datetimeselectorsop';

export interface DialogOperationFeedbackFields {
  Unit?: string;
  Operation?: string;
  Date?: string;
  Quantity?: string;
  FeedbackLocked?: string;
  Description?: string;
}

export class DialogOperationFeedback extends DialogSOP<DialogOperationFeedbackFields> {
  public static title = 'Operation Feedback';

  public ddlUnit = new DropDownListSOP('DropDownListUnit');
  public ddlOperation = new DropDownListSOP('DropDownListOperation');
  public dtDate = new DateTimeSelectorSOP('DateTimeSelectorDateTime');
  public efQuantity = new EditFieldSOP('EditFieldQuantity');
  public cbFeedbackLocked = new CheckboxSOP('CheckBoxIsLocked');
  public efDescription = new EditFieldSOP('EditFieldDescription');

  public constructor() {
    super('DialogCreateEditFeedbackOperation');

    // Set UI element mapping to pair the UI name to the UI element for use in DialogSOP to find the UI object to set value or verify value
    // This prevents each new Dialog to duplicate code just to set/verify UI element value
    this._uiMap.set('Unit', this.ddlUnit);
    this._uiMap.set('Operation', this.ddlOperation);
    this._uiMap.set('Date', this.dtDate);
    this._uiMap.set('Quantity', this.efQuantity);
    this._uiMap.set('FeedbackLocked', this.cbFeedbackLocked);
    this._uiMap.set('Description', this.efDescription);
  }
}
